package cn.com.infosec.asn1.cmp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class PBMParameter extends ASN1Encodable {
   private ASN1OctetString salt;
   private AlgorithmIdentifier owf;
   private DERInteger iterationCount;
   private AlgorithmIdentifier mac;

   private PBMParameter(ASN1Sequence seq) {
      this.salt = ASN1OctetString.getInstance(seq.getObjectAt(0));
      this.owf = AlgorithmIdentifier.getInstance(seq.getObjectAt(1));
      this.iterationCount = DERInteger.getInstance(seq.getObjectAt(2));
      this.mac = AlgorithmIdentifier.getInstance(seq.getObjectAt(3));
   }

   public static PBMParameter getInstance(Object o) {
      if (o instanceof PBMParameter) {
         return (PBMParameter)o;
      } else if (o instanceof ASN1Sequence) {
         return new PBMParameter((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   public AlgorithmIdentifier getOwf() {
      return this.owf;
   }

   public DERInteger getIterationCount() {
      return this.iterationCount;
   }

   public AlgorithmIdentifier getMac() {
      return this.mac;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.salt);
      var1.add(this.owf);
      var1.add(this.iterationCount);
      var10000.add(this.mac);
      return new DERSequence(var1);
   }
}
